import { DataSource } from '@angular/cdk/table';

import { BehaviorSubject, Observable, merge, of } from 'rxjs';
import { map } from 'rxjs/operators';

import { CollectionViewer } from '@angular/cdk/collections';

import { BettingHistory } from 'src/modules/game/model/betting-history.model';
import { BettingHistoryService } from 'src/modules/game/service/betting-history.service';

import { FormControl, FormGroup, Validators, FormArray } from '@angular/forms';
import { BettingResultName } from 'src/modules/game/type/betting-result.type';

const ELEMENT_DATA: BettingHistory[] = [
  {
    id: 1,
    league: 1,
    sportsEvents: null,
    user: 1,
    moneyLog: 20000,
    bettingMoney: 10000,
    predictMoney: 100,
    realMoney: 11111,
    bettingResult: BettingResultName.FAILURE,
    createdBy: 1,
    updatedBy: 1,
    updatedAt: null,
    createdAt: null
  },
  {
    id: 2,
    league: 1,
    sportsEvents: null,
    user: 1,
    moneyLog: 20000,
    bettingMoney: 10000,
    predictMoney: 100,
    realMoney: 11111,
    bettingResult: BettingResultName.FAILURE,
    createdBy: 1,
    updatedBy: 1,
    updatedAt: null,
    createdAt: null
  },
  {
    id: 3,
    league: 1,
    sportsEvents: null,
    user: 1,
    moneyLog: 20000,
    bettingMoney: 10000,
    predictMoney: 100,
    realMoney: 11111,
    bettingResult: BettingResultName.FAILURE,
    createdBy: 1,
    updatedBy: 1,
    updatedAt: null,
    createdAt: null
  }
];

export class BetHistoryDataSource extends DataSource<BettingHistory> {
  private _objectStore: BettingHistory[] = [];
  private _ObjectsSubject$ = new BehaviorSubject<BettingHistory[]>([]);
  private _loadingSubject$ = new BehaviorSubject<boolean>(false);

  public loading$ = this._loadingSubject$.asObservable();
  public formg: FormGroup;

  constructor(private betHistoryService: BettingHistoryService) {
    super();
  }

  connect(collectionViewer: CollectionViewer): Observable<BettingHistory[]> {
    // return this.fixBonusService.getAll().pipe(
    //   map(res => {
    //     res.forEach(m => this._objectStore.push(m as FixBonus));
    //     this._ObjectsSubject$.next(this._objectStore);
    //     let fa = <FormArray>this.formg.get('formarray');
    //     res.forEach(r => fa.push(this.createRowFormGroup(r)));
    //     return res;
    //   })
    // );
    return of(ELEMENT_DATA).pipe(
      map(res => {
        res.forEach(m => this._objectStore.push(m as BettingHistory));
        this._ObjectsSubject$.next(this._objectStore);
        let fa = <FormArray>this.formg.get('formarray');
        res.forEach(r => fa.push(this.createRowFormGroup(r)));
        return res;
      })
    );
  }

  // id: 3,
  // thumbNail: '/images/thumbname/3.jpg',
  // title: '친구초대 이벤트',
  // imageWidth: 200,
  // imageHeight: 200,
  // imageX: 100,
  // imageY: 100,
  // openStatus: true,
  // updatedAt: null,
  // createdAt: null
  createRowFormGroup(r: BettingHistory): FormGroup {
    let f = new FormGroup({
      title: this.createNewFormContorl(r, 'title'),
      imageWidth: this.createNewFormContorl(r, 'imageWidth'),
      imageHeight: this.createNewFormContorl(r, 'imageHeight'),
      imageX: this.createNewFormContorl(r, 'imageX'),
      imageY: this.createNewFormContorl(r, 'imageY'),
      openStatus: this.createNewFormContorl(r, 'openStatus')
    });
    return f;
  }

  createNewFormContorl(r: BettingHistory, propName: string): FormControl {
    let m = new FormControl(r[propName], Validators.required);
    m.valueChanges.subscribe(val => {
      r[propName] = val;
    });
    return m;
  }

  disconnect(collectionViewer: CollectionViewer): void {
    this._ObjectsSubject$.complete();
    this._loadingSubject$.complete();
  }
}
