import {
  Component,
  OnDestroy,
  OnInit,
  ViewEncapsulation,
  ViewChild,
  ElementRef
} from '@angular/core';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort } from '@angular/material/sort';
import { DataSource } from '@angular/cdk/collections';
import { FormBuilder, FormGroup, FormArray } from '@angular/forms';
import { Subject } from 'rxjs';
import { takeUntil } from 'rxjs/operators';

import { fuseAnimations } from 'src/@fuse/animations';

import { PopupConfigService } from 'src/modules/infos/service/popup-config.service';
import { PopupConfigDataSource } from './popup-config.data-source';
@Component({
  selector: 'app-popup-config',
  templateUrl: './popup-config.component.html',
  styleUrls: ['./popup-config.component.scss'],
  encapsulation: ViewEncapsulation.None,
  animations: fuseAnimations
})
export class PopupConfigComponent implements OnInit, OnDestroy {
  dataSource: PopupConfigDataSource = new PopupConfigDataSource(
    this.popupConfigService
  );
  displayedColumns = [
    'idx',
    'thumbNail',
    'title',
    'imgWidth',
    'imgHegith',
    'imgX',
    'imgY',
    'openStatus',
    'saveBtn'
  ];

  public mtformgroup: FormGroup;
  public mtformarray: FormArray;

  // @ViewChild(MatPaginator, { static: true })
  // paginator: MatPaginator;

  // @ViewChild('filter', { static: true })
  // filter: ElementRef;

  // @ViewChild(MatSort, { static: true })
  // sort: MatSort;

  // Private
  private unsubscribeAll: Subject<any>;

  constructor(
    private fb: FormBuilder,
    private popupConfigService: PopupConfigService
  ) {
    // Set the private defaults
    this.unsubscribeAll = new Subject();
  }

  // -----------------------------------------------------------------------------------------------------
  // @ Lifecycle hooks
  // -----------------------------------------------------------------------------------------------------

  /**
   * On init
   */
  ngOnInit(): void {
    // Subscribe to update order on changes
    this.mtformarray = this.fb.array([]);
    this.mtformgroup = this.fb.group({ formarray: this.mtformarray });
    this.dataSource.formg = this.mtformgroup;
  }

  /**
   * On destroy
   */
  ngOnDestroy(): void {
    // Unsubscribe from all subscriptions
    this.unsubscribeAll.next();
    this.unsubscribeAll.complete();
  }
}
