import { DataSource } from '@angular/cdk/table';

import { BehaviorSubject, Observable, merge, of } from 'rxjs';
import { map } from 'rxjs/operators';

import { CollectionViewer } from '@angular/cdk/collections';

import { PopupConfig } from 'src/modules/infos/model/popup-config.model';
import { PopupConfigService } from 'src/modules/infos/service/popup-config.service';

import { FormControl, FormGroup, Validators, FormArray } from '@angular/forms';

const ELEMENT_DATA: PopupConfig[] = [
  {
    id: 1,
    thumbNail: '/images/thumbname/1.jpg',
    title: '오픈기념 이벤트',
    imgWidth: 200,
    imgHeight: 200,
    imgX: 100,
    imgY: 100,
    openStatus: true,
    updatedAt: null,
    createdAt: null,
    createdBy: null,
    updatedBy: null
  },
  {
    id: 2,
    thumbNail: '/images/thumbname/2.jpg',
    title: '첫충전 이벤트',
    imgWidth: 200,
    imgHeight: 200,
    imgX: 100,
    imgY: 100,
    openStatus: true,
    updatedAt: null,
    createdAt: null,
    createdBy: null,
    updatedBy: null
  },
  {
    id: 3,
    thumbNail: '/images/thumbname/3.jpg',
    title: '친구초대 이벤트',
    imgWidth: 200,
    imgHeight: 200,
    imgX: 100,
    imgY: 100,
    openStatus: true,
    updatedAt: null,
    createdAt: null,
    createdBy: null,
    updatedBy: null
  }
];

export class PopupConfigDataSource extends DataSource<PopupConfig> {
  private _objectStore: PopupConfig[] = [];
  private _ObjectsSubject$ = new BehaviorSubject<PopupConfig[]>([]);
  private _loadingSubject$ = new BehaviorSubject<boolean>(false);

  public loading$ = this._loadingSubject$.asObservable();
  public formg: FormGroup;

  constructor(private fixBonusService: PopupConfigService) {
    super();
  }

  connect(collectionViewer: CollectionViewer): Observable<PopupConfig[]> {
    // return this.fixBonusService.getAll().pipe(
    //   map(res => {
    //     res.forEach(m => this._objectStore.push(m as FixBonus));
    //     this._ObjectsSubject$.next(this._objectStore);
    //     let fa = <FormArray>this.formg.get('formarray');
    //     res.forEach(r => fa.push(this.createRowFormGroup(r)));
    //     return res;
    //   })
    // );
    return of(ELEMENT_DATA).pipe(
      map(res => {
        res.forEach(m => this._objectStore.push(m as PopupConfig));
        this._ObjectsSubject$.next(this._objectStore);
        let fa = <FormArray>this.formg.get('formarray');
        res.forEach(r => fa.push(this.createRowFormGroup(r)));
        return res;
      })
    );
  }

  // id: 3,
  // thumbNail: '/images/thumbname/3.jpg',
  // title: '친구초대 이벤트',
  // imgWidth: 200,
  // imgHeight: 200,
  // imgX: 100,
  // imgY: 100,
  // openStatus: true,
  // updatedAt: null,
  // createdAt: null,
  // createdBy: null,
  // updatedBy: null
  createRowFormGroup(r: PopupConfig): FormGroup {
    let f = new FormGroup({
      title: this.createNewFormContorl(r, 'title'),
      imgWidth: this.createNewFormContorl(r, 'imgWidth'),
      imgHeight: this.createNewFormContorl(r, 'imgHeight'),
      imgX: this.createNewFormContorl(r, 'imgX'),
      imgY: this.createNewFormContorl(r, 'imgY'),
      openStatus: this.createNewFormContorl(r, 'openStatus')
    });
    return f;
  }

  createNewFormContorl(r: PopupConfig, propName: string): FormControl {
    let m = new FormControl(r[propName], Validators.required);
    m.valueChanges.subscribe(val => {
      r[propName] = val;
    });
    return m;
  }

  disconnect(collectionViewer: CollectionViewer): void {
    this._ObjectsSubject$.complete();
    this._loadingSubject$.complete();
  }
}
